==> jackrabbit-oak-1.4.26-src.zip: jackrabbit-oak-1.4.26/oak-doc/src/site/markdown/participating.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
  -->

Participating
-------------

The best place for Oak-related discussions is the [oak-dev@](mailto:oak-dev@jackrabbit.apache.org)
mailing list. To subscribe, send a message to [oak-dev-subscribe@]
(mailto:oak-dev-subscribe@jackrabbit.apache.org). 

Use the [OAK issue tracker](https://issues.apache.org/jira/browse/OAK) to submit issues, comments 
or patches. To subscribe to issue notifications, send a message to [oak-issues@]
(mailto:oak-issues-subscribe@jackrabbit.apache.org). 

The latest Oak sources are available for checkout from [svn][1] and can also be browsed using the 
[ViewVC][3] interface. You can also [fork them][2] on GitHub. To subscribe to commit notifications, send a message to [oak-commits@]
(mailto:oak-commits-subscribe@jackrabbit.apache.org).

For more details related to various mailing list have a look at http://jackrabbit.apache.org/mailing-lists.html
 
[1]: https://svn.apache.org/repos/asf/jackrabbit/oak/trunk
[2]: https://github.com/apache/jackrabbit-oak
[3]: http://svn.apache.org/viewvc/jackrabbit/oak/trunk/

==> jackrabbit-oak-1.22.23-src.zip: jackrabbit-oak-1.22.23/oak-doc/src/site/markdown/participating.md <==
<!--
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
  -->

Participating
-------------

The best place for Oak-related discussions is the [oak-dev@](mailto:oak-dev@jackrabbit.apache.org)
mailing list. To subscribe, send a message to [oak-dev-subscribe@]
(mailto:oak-dev-subscribe@jackrabbit.apache.org). 

Use the [OAK issue tracker](https://issues.apache.org/jira/browse/OAK) to submit issues, comments 
or patches. To subscribe to issue notifications, send a message to [oak-issues@]
(mailto:oak-issues-subscribe@jackrabbit.apache.org). 

The latest Oak sources are available for checkout from [svn][1] and can also be browsed using the 
[ViewVC][3] interface. You can also [fork them][2] on GitHub. To subscribe to commit notifications, 
send a message to [oak-commits@] (mailto:oak-commits-subscribe@jackrabbit.apache.org).

For more details related to various mailing list have a look at http://jackrabbit.apache.org/mailing-lists.html

We generally follow a [CTR](https://www.apache.org/foundation/glossary.html#CommitThenReview) policy. 
However it is up to each individual committer to pro-actively ask for a review of a patch on 
oak-dev@ or to even call for a [RTC](https://www.apache.org/foundation/glossary.html#ReviewThenCommit). 
Special care should be taken with backports to maintenance branches. Back ports bear a certain risk 
of introducing regressions to otherwise stable branches. Each back ported change should be carefully 
evaluated for its potential impact, risk and possible mitigation. It is the responsibility of each 
committer to asses these and ask for advise or reviewing on oak-dev@ if uncertain. Whether using 
RTC or CTR is up to the committer.
 
[1]: https://svn.apache.org/repos/asf/jackrabbit/oak/trunk
[2]: https://github.com/apache/jackrabbit-oak
[3]: http://svn.apache.org/viewvc/jackrabbit/oak/trunk/
